/* 
irrigating.c
irrigating  - irrigating seeds in soil - increase transfer pools

*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*
Biome-BGCMuSo v6.1.
Copyright 2020, D. Hidy [dori.hidy@gmail.com]
Hungarian Academy of Sciences, Hungary
See the website of Biome-BGCMuSo at http://nimbus.elte.hu/bbgc/ for documentation, model executable and example input files.
*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*

*/

#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <time.h>
#include <math.h>
#include "ini.h"     
#include "pointbgc_struct.h"
#include "bgc_struct.h"
#include "pointbgc_func.h"
#include "bgc_constants.h"

int irrigating(const control_struct* ctrl, const irrigating_struct* IRG, const siteconst_struct* sitec, epvar_struct* epv, wflux_struct* wf)
{
	/* irrigating parameters */	   
	
	int errflag=0;
	int layer, condIRG;
	double critVWCbef, critVWCaft, condIRG_amount;

	int md, year;

	year = ctrl->simstartyear + ctrl->simyr;
	md = IRG->mgmdIRG-1;


	critVWCbef=condIRG_amount=0;
	condIRG=0;

	/*  1. CALCULATING FLUXES: amount of water (kgH2O) * (%_to_prop) */
	if (IRG->IRG_num && md >= 0)
	{
		if (year == IRG->IRGyear_array[md] && ctrl->month == IRG->IRGmonth_array[md] && ctrl->day == IRG->IRGday_array[md])
		{
 			wf->IRG_to_prcp=IRG->IRGquantity_array[md];
		}
		
		else
			wf->IRG_to_prcp=0;
	}


	/* 2. conditional irrigating: in case of dry soil */
	if (IRG->condIRG_flag)
	{
		/* in case of critical VWCratio is used */
		if (IRG->befVWCratio_condIRG != (double) DATA_GAP)
		{
			critVWCbef = epv->vwcWP_RZ + IRG->befVWCratio_condIRG * (epv->vwcFC_RZ - epv->vwcWP_RZ);
			if (epv->vwc_RZ < critVWCbef) condIRG = 1;
		}
		/* in case of critical SMSI is used */
		else
		{
			if (epv->SMSI > IRG->befSMSI_condIRG) condIRG = 1;
		}

		/* if condIRG - calculation of irrigating amount */
		if (condIRG)
		{
			for (layer = 0; layer < epv->n_maxrootlayers; layer++)
			{
				critVWCaft = epv->vwcWP_RZ + IRG->aftVWCratio_condIRG * (epv->vwcFC_RZ - epv->vwcWP_RZ);
				if (critVWCaft < epv->vwc[layer])
				{
					printf("ERROR in conditional irrigating calculation (irrigating.c)\n");
					errflag=1;
				}
				condIRG_amount += (critVWCaft- epv->vwc[layer]) * (sitec->soillayer_thickness[layer]) * water_density;
			}
		}
			
		/* irrigating amount is added to IRG_to_prcp (limitation is possible based on condIRG parameters*/	
		if (condIRG_amount)
		{
			if (condIRG_amount <= IRG->maxAMOUNT_condIRG)
			{
				wf->IRG_to_prcp = condIRG_amount;
				if (ctrl->onscreen && ctrl->spinup == 0) printf("conditional IRRIGATING on %i%s%i\n", ctrl->month, "/", ctrl->day);
			}
			else
			{
				wf->IRG_to_prcp = IRG->maxAMOUNT_condIRG;
				if (ctrl->onscreen && ctrl->spinup == 0) printf("limited conditional IRRIGATING on %i%s%i\n", ctrl->month, "/", ctrl->day);
			}
		}

	}
	

   return (errflag);
}
	